@@ -1,5 +1,8 @@
 import numpy
-import xraylib
+
+try: import xraylib
+except: print("xraylib is not available.")
+
 import scipy.constants as codata
 
 # needed by bragg_calc
@@ -137,7 +140,7 @@ def lorentz(theta_bragg_deg, return_what=0):
 
 # OBSOLETE.... USE bragg_calc2() INSTEAD!
 def bragg_calc(descriptor="Si", hh=1, kk=1, ll=1, temper=1.0, emin=5000.0, emax=15000.0, estep=100.0, fileout=None,
-               material_constants_library=xraylib):
+               material_constants_library=None):
     """
     OBSOLETE.... USE bragg_calc2() INSTEAD!
     Preprocessor for Structure Factor (FH) calculations. It calculates the basic ingredients of FH.
@@ -173,6 +176,7 @@ def bragg_calc(descriptor="Si", hh=1, kk=1, ll=1, temper=1.0, emin=5000.0, emax=
 
     """
 
+    if material_constants_library is None: material_constants_library = xraylib
 
     output_dictionary = {}
 
@@ -582,7 +586,7 @@ def bragg_calc2(descriptor="YB66", hh=1, kk=1, ll=1, temper=1.0,
                 fileout=None,
                 do_not_prototype=0, # 0=use site groups (recommended), 1=use all individual sites
                 verbose=True,
-                material_constants_library=xraylib,
+                material_constants_library=None,
                 ):
     """
     Preprocessor for Structure Factor (FH) calculations. It calculates the basic ingredients of FH.
@@ -623,6 +627,9 @@ def bragg_calc2(descriptor="YB66", hh=1, kk=1, ll=1, temper=1.0,
     dict
         a dictionary with all ingredients of the structure factor.
     """
+
+    if material_constants_library is None: material_constants_library = xraylib
+
     output_dictionary = {}
 
     codata_e2_mc2 = codata.e ** 2 / codata.m_e / codata.c ** 2 / (4 * numpy.pi * codata.epsilon_0)  # in m
@@ -956,7 +963,7 @@ def TemperFactor(sinTheta_lambda, anisos, Miller={'h':1,'k':1,'l':1}, cell={'a':
     return results
 
 def mare_calc(descriptor, H, K, L, HMAX, KMAX, LMAX, FHEDGE, DISPLAY, lambda1, deltalambda, PHI, DELTAPHI,
-              material_constants_library=xraylib,verbose=0):
+              material_constants_library=None,verbose=0):
     """
     Calculates:
 
@@ -1035,6 +1042,8 @@ def mare_calc(descriptor, H, K, L, HMAX, KMAX, LMAX, FHEDGE, DISPLAY, lambda1, d
 
     """
 
+    if material_constants_library is None: material_constants_library = xraylib
+
     list_of_scripts = []
 
 
@@ -1450,7 +1459,7 @@ def mare_calc(descriptor, H, K, L, HMAX, KMAX, LMAX, FHEDGE, DISPLAY, lambda1, d
 def calc_temperature_factor(temperature, crystal='Si', debyeTemperature=644.92,
                             millerIndex=[1, 1, 1], atomicMass=28.09,
                             dSpacing=3.1354162886330583,
-                            material_constants_library=xraylib
+                            material_constants_library=None
                           ):
     """
     Calculates the (Debye) temperature factor for single crystals. See [1]_, [2]_.
@@ -1502,6 +1511,7 @@ def calc_temperature_factor(temperature, crystal='Si', debyeTemperature=644.92,
     #     >>> calc_temperature_factor(80, crystal='Si', millerIndex=[1,1,1], debyeTemperature=644.92, atomicMass=28.09, dSpacing=3.1354163)
     #     0.9955698950510736
 
+    if material_constants_library is None: material_constants_library = xraylib
 
     def debyeFunc(x):
         return x / (numpy.exp(-x) - 1)
