@@ -5,7 +5,10 @@ import os
 import numpy
 import scipy.constants as codata
 import h5py
-import xraylib
+
+from dabax.dabax_xraylib import DabaxXraylib
+try: import xraylib
+except: print("xraylib is not available.")
 
 from xoppylib.scattering_functions.fresnel import reflectivity_fresnel
 from xoppylib.xoppy_xraylib_util import nist_compound_list, density
@@ -75,7 +78,10 @@ def calculate_component_absorbance_and_transmittance(
     multilayer_file='',
     external_reflectivity_file='',
     verbose=1,
+    material_constants_library=None,
     ):
+
+    if material_constants_library is None: material_constants_library = xraylib
     #
     # important: the transmittance calculated here is referred on axes perp to the beam
     # therefore they do not include geometrical corrections for correct integral
@@ -99,7 +105,7 @@ def calculate_component_absorbance_and_transmittance(
         try:  # apply written value
             rho = float(dens)
         except:  # in case of ?
-            rho = density(substance)
+            rho = density(substance, material_constants_library=material_constants_library)
             print("Density for %s: %g g/cm3" % (substance, rho))
         dens = rho
 
@@ -160,7 +166,7 @@ def calculate_component_absorbance_and_transmittance(
 
     if flags == 0:  # filter
         for j, energy in enumerate(e):
-            tmp = xraylib.CS_Total_CP(substance, energy / 1000.0)
+            tmp = material_constants_library.CS_Total_CP(substance, energy / 1000.0)
             transmittance[j, :, :] = numpy.exp(-tmp * dens * (thick / 10.0))
 
         # rotation
@@ -187,7 +193,7 @@ def calculate_component_absorbance_and_transmittance(
         tmp = numpy.zeros(e.size)
 
         for j, energy in enumerate(e):
-            tmp[j] = xraylib.Refractive_Index_Re(substance, energy / 1000.0, dens)
+            tmp[j] = material_constants_library.Refractive_Index_Re(substance, energy / 1000.0, dens)
 
         if tmp[0] == 0.0:
             raise Exception("Probably the substrance %s is wrong" % substance)
@@ -196,7 +202,7 @@ def calculate_component_absorbance_and_transmittance(
         beta = numpy.zeros(e.size)
 
         for j, energy in enumerate(e):
-            beta[j] = xraylib.Refractive_Index_Im(substance, energy / 1000.0, dens)
+            beta[j] = material_constants_library.Refractive_Index_Im(substance, energy / 1000.0, dens)
 
         try:
             (rs, rp, runp) = reflectivity_fresnel(refraction_index_beta=beta, refraction_index_delta=delta, \
@@ -310,7 +316,7 @@ def calculate_component_absorbance_and_transmittance(
         thick_interpolated = numpy.abs(thick_interpolated - thick_interpolated_back)
 
         for j, energy in enumerate(e):
-            tmp = xraylib.CS_Total_CP(substance, energy / 1000.0)
+            tmp = material_constants_library.CS_Total_CP(substance, energy / 1000.0)
             transmittance[j, :, :] = numpy.exp(-tmp * dens * (thick_interpolated[:, :] / 10.0))
 
         absorbance = 1.0 - transmittance
